summaryrefslogtreecommitdiffstats
path: root/kdeui/krootpixmap.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kdeui/krootpixmap.h
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdeui/krootpixmap.h')
-rw-r--r--kdeui/krootpixmap.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kdeui/krootpixmap.h b/kdeui/krootpixmap.h
index d714c93ef..60f9ac549 100644
--- a/kdeui/krootpixmap.h
+++ b/kdeui/krootpixmap.h
@@ -43,7 +43,7 @@ class KRootPixmapData;
* @author Geert Jansen <jansen@kde.org>
* @version $Id$
*/
-class KDEUI_EXPORT KRootPixmap: public QObject
+class KDEUI_EXPORT KRootPixmap: public TQObject
{
Q_OBJECT
@@ -137,16 +137,16 @@ public slots:
* Repaints the widget background. Normally, you shouldn't need this
* as it is handled automatically.
*
* @param force Force a repaint, even if the contents did not change.
*/
- void repaint( bool force );
+ void tqrepaint( bool force );
/**
* Repaints the widget background. Normally, you shouldn't need this
* as it is handled automatically. This is equivalent to calling
- * repaint( false ).
+ * tqrepaint( false ).
*/
- void repaint();
+ void tqrepaint();
/**
* Enables custom handling of the background painting. If custom
@@ -137,16 +137,16 @@ public slots:
* as it is handled automatically.
*
- * @param force Force a repaint, even if the contents did not change.
+ * @param force Force a tqrepaint, even if the contents did not change.
*/